pub enum SourceType {
Static {
duration: f32,
},
Dynamic,
}Expand description
The type of the DspSource.
Variants
Static
Indicates that the DSP source is static. This means that the playing sound is simply a collection of bytes. Therefore, the audio is of definite length, and the sound last for the given duration.
See Wave32 on how this is converted.
Dynamic
Indicates that the DSP source is dynamic. This means that the playing sound last forever. Internally, each frame is computed manually, and not referenced from an internal collection of bytes.
See Iter.